@@ -474,11 +474,11 @@ class Rouge(object):
 
             for m in self.metrics:
                 fn = Rouge.AVAILABLE_METRICS[m]
-                sc = fn(
-                    hyp,
-                    ref,
-                    exclusive=self.exclusive)
-                sen_score[m] = {s: sc[s] for s in self.stats}
+                try:
+                    sc = fn(hyp, ref, exclusive=self.exclusive)
+                    sen_score[m] = {s: sc[s] for s in self.stats}
+                except ValueError as err:
+                    sen_score[m] = {s: 0.0 for s in self.stats}
 
             scores.append(sen_score)
         return scores
